@@ -1,4 +1,5 @@
-import requests,datetime,time,warnings,json
+import requests,datetime,time,warnings,json,calendar,math,os
+from datetime import date
 from pandas.io.json import json_normalize
 import pandas as pd
 import numpy as np
@@ -83,38 +84,58 @@ class Sing_Qimai:
 
 # 计算七麦外的其他备用工具；
 class Qimai_Outside_Tool:
-    def __init__(self, data_info):
-        self.data_info = data_info
+    def __init__(self, *args):
+        self.data_info = args
 
     def json_to_df(self):
-        self.json_df = json_normalize(self.data_info)
+        self.json_df = json_normalize(self.data_info[0])
         return self.json_df
 
     def list_to_df(self):
-        self.list_df = pd.DataFrame(self.data_info)
+        self.list_df = pd.DataFrame(self.data_info[0])
         return self.list_df
 
     def unix_time(self):
         # 世界标准时间
-        date_now = datetime.datetime.strptime(self.data_info, '%Y-%m-%d %H:%M:%S')
+        date_now = datetime.datetime.strptime(self.data_info[0], '%Y-%m-%d %H:%M:%S')
         # 北京时间UTC+8
         cst_time = date_now.astimezone(datetime.timezone(datetime.timedelta(hours=-8))).strftime("%Y-%m-%d %H:%M:%S")
         return cst_time
 
     def time_to_date(self):
-        if len(str(self.data_info)) == 13:
-            self.data_info = int(self.data_info/1000)
-        timeArray = time.localtime(self.data_info)
-        otherStyleTime = time.strftime("%Y-%m-%d", timeArray)
+        if len(str(self.data_info[0])) == 13:
+            self.run_time = int(self.data_info[0]/1000)
+        else:
+            self.run_time = self.data_info[0]
+        timeArray = time.localtime(self.run_time)
+        otherStyleTime = time.strftime("%Y-%m-%d %H:%M:%S", timeArray)
         return otherStyleTime
 
     def date_to_time(self):
-        if len(str(self.data_info)) == 10:
-            self.data_info = self.data_info + ' 00:00:00'
-        timeArray = time.strptime(self.data_info, "%Y-%m-%d %H:%M:%S")
+        if len(str(self.data_info[0])) == 10:
+            self.run_date = self.data_info[0] + ' 00:00:00'
+        timeArray = time.strptime(self.run_date, "%Y-%m-%d %H:%M:%S")
         timeStamp = int(time.mktime(timeArray))
         return timeStamp
 
+    def get_month_time(self):
+        day_start = datetime.date.fromisoformat(str(self.data_info[0]))
+        day_end = datetime.date.fromisoformat(str(self.data_info[1]))
+        # monthRange_start = calendar.monthrange(day_start.year, day_start.month)
+        monthRange_end = calendar.monthrange(day_end.year, day_end.month)
+        start_time = str(day_start)[:8] + str('01')
+        end_time = str(day_end)[:8] + str(monthRange_end[1])
+        return start_time, end_time
+
+    def calc_interval_time(self):
+        spider_time_datetime = datetime.datetime.strptime(str(self.data_info[0]), '%Y-%m-%d %H:%M:%S')
+        rank_out_datetime = datetime.datetime.strptime(str(self.data_info[1]), '%Y-%m-%d %H:%M:%S')
+        interval_seconds = (rank_out_datetime - spider_time_datetime).seconds
+        m, s = divmod(interval_seconds, 60)
+        h, m = divmod(m, 60)
+        interval_time = "%02d小时%02d分钟%02d秒" % (h, m, s)  # 计算间隔时间；
+        return interval_time
+
     def calc_overlap_days(self, s1, e1, s2, e2):
         latest_start = max(s1, s2)
         earliest_end = min(e1, e2)
@@ -129,12 +150,12 @@ class Qimai_Outside_Tool:
 
     def trend_analysis(self):
         self.alpha = 0.05
-        n = len(self.data_info)
+        n = len(self.data_info[0])
         s = 0
         for k in range(n - 1):
             for j in range(k + 1, n):
-                s += np.sign(self.data_info[j] - self.data_info[k])
-        unique_x, tp = np.unique(self.data_info, return_counts=True)
+                s += np.sign(self.data_info[0][j] - self.data_info[0][k])
+        unique_x, tp = np.unique(self.data_info[0], return_counts=True)
         g = len(unique_x)
         if n == g:
             var_s = (n * (n - 1) * (2 * n + 5)) / 18
@@ -275,7 +296,7 @@ class Get_App_SamePubApp(Get_App_Appinfo, Qimai_Diy_Var):
         self.app_samePubApp = res.json()['samePubApps']
         return self.app_samePubApp
 
-    def get_app_genid(self):
+    def get_app_genName(self):
         self.get_samePubApp()
         for info in self.app_samePubApp:
             if str(info['appInfo']['appId']) == str(self.appid):
